@@ -14,5 +14,7 @@
 
 import django.dispatch
 
-pre_user_save = django.dispatch.Signal(providing_args=['attributes', 'user_modified'])
-post_authenticated = django.dispatch.Signal(providing_args=['session_info'])
+pre_user_save = django.dispatch.Signal(
+    providing_args=['attributes', 'user_modified'])
+post_authenticated = django.dispatch.Signal(
+    providing_args=['session_info', 'request'])
