@@ -110,9 +110,20 @@ class LoginView(SPConfigMixin, View):
         will be rendered.
     """
 
-    wayf_template = 'djangosaml2/wayf.html'
-    authorization_error_template = 'djangosaml2/auth_error.html'
-    post_binding_form_template = 'djangosaml2/post_binding_form.html'
+    wayf_template = getattr(
+        settings,
+        'SAML2_CUSTOM_WAYF_TEMPLATE','djangosaml2/wayf.html'
+    )
+    authorization_error_template = getattr(
+        settings,
+        'SAML2_CUSTOM_AUTHORIZATION_ERROR_TEMPLATE',
+        'djangosaml2/auth_error.html'
+    )
+    post_binding_form_template = getattr(
+        settings,
+        'SAML2_CUSTOM_POST_BINDING_FORM_TEMPLATE',
+        'djangosaml2/post_binding_form.html'
+    )
 
     def get_next_path(self, request: HttpRequest) -> str:
         ''' Returns the path to put in the RelayState to redirect the user to after having logged in.
@@ -162,9 +173,9 @@ class LoginView(SPConfigMixin, View):
         if ac:
             sso_kwargs["requested_authn_context"] = RequestedAuthnContext(
                     authn_context_class_ref=[
-                        AuthnContextClassRef(ac['authn_context_class_ref']),
+                        AuthnContextClassRef(ref) for ref in ac['authn_context_class_ref']
                     ],
-                    comparison = ac.get('comparison', "minimum"),
+                    comparison=ac.get('comparison', "minimum"),
                 )
 
     def load_sso_kwargs(self, sso_kwargs):
@@ -349,7 +360,7 @@ class LoginView(SPConfigMixin, View):
                         },
                     })
                 except TemplateDoesNotExist as e:
-                    logger.error(
+                    logger.debug(
                         f'TemplateDoesNotExist: [{self.post_binding_form_template}] - {e}'
                     )
 
@@ -596,18 +607,25 @@ class LogoutInitView(LoginRequiredMixin, SPConfigMixin, View):
             logger.warning(
                 'The session does not contain the subject id for user %s', request.user)
 
+        _error = None
         try:
             result = client.global_logout(subject_id)
         except LogoutError as exp:
             logger.exception(
                 'Error Handled - SLO not supported by IDP: {}'.format(exp))
-            auth.logout(request)
-            state.sync()
-            return self.handle_unsupported_slo_exception(request, exp)
+            _error = exp
+        except UnsupportedBinding as exp:
+            logger.exception(
+                'Error Handled - SLO - unsupported binding by IDP: {}'.format(exp))
+            _error = exp
 
         auth.logout(request)
         state.sync()
 
+        if _error:
+            return self.handle_unsupported_slo_exception(request, _error)
+
+
         if not result:
             logger.error(
                 "Looks like the user %s is not logged in any IdP/AA", subject_id)
